==> alogin-7.x-1.0.zip: alogin/src/Alogin.php <==
<?php

use Sonata\GoogleAuthenticator\GoogleAuthenticator;

class Alogin {
  protected $secret, $issuer, $currentUser, $uid = 0;
  protected $table = 'alogin_user_settings';

  public function __construct($uid) {
    global $user;
    $this->uid = $uid;
    $this->currentUser = $user;
    $this->issuer = variable_get('site_name');
    $this->secret = $this->getSecret() ? $this->getSecret() : $this->setSecret();
  }

  public function getQr() {
    $g = new GoogleAuthenticator();
    return $g->getURL($this->currentUser->name, str_replace(' ', '', $this->issuer) , $this->secret);
  }

  public function check($code) {
    $g = new GoogleAuthenticator();
    return $g->checkCode($this->secret, $code);
  }

  public function select($fields = []) {
    $select = db_select($this->table, 'a')
              ->fields('a', $fields)
              ->condition('uid', $this->uid, '=')
              ->execute()
              ->fetchAssoc();
    return $select;
  }

  public function getSecret() {
    if($secret = $this->select(['secret'])) {
      return $secret['secret'];
    }
    return false;
  }

  public function setSecret() {
    $g = new GoogleAuthenticator();
    $secret = $g->generateSecret();
    db_insert($this->table)->fields([
      'uid' => $this->uid,
      'secret' => $secret,
    ])->execute();
    return $secret;
  }

  public function enable($enable = 0) {
    return db_update($this->table)
          ->fields(['enabled' => $enable])
          ->condition('uid', $this->uid, '=')
          ->execute();
  }

  public function enabled() {
    $enabled = db_select($this->table, 'a')
          ->fields('a', ['enabled'])
          ->condition('uid', $this->uid, '=')
          ->execute()
          ->fetchAssoc();
    return $enabled['enabled'];
  }
}

==> alogin-7.x-1.5.zip: alogin/src/Alogin.php <==
<?php

use PragmaRX\Google2FAQRCode\Google2FA;

class Alogin {
  protected $secret, $issuer, $currentUser, $uid = 0;
  protected $table = 'alogin_user_settings';

  public function __construct($uid) {
    global $user;
    $this->uid = $uid;
    $this->currentUser = $user;
    $this->issuer = variable_get('site_name');
    $this->secret = $this->getSecret() ? $this->getSecret() : $this->setSecret();
  }

  public function getQr() {
    $g = new Google2FA();
    return $g->getQRCodeInline($this->currentUser->name, str_replace(' ', '', $this->issuer) , $this->secret);
  }

  public function check($code) {
    $g = new Google2FA();
    return $g->verifyKey($this->secret, $code);
  }

  public function select($fields = []) {
    $select = db_select($this->table, 'a')
              ->fields('a', $fields)
              ->condition('uid', $this->uid, '=')
              ->execute()
              ->fetchAssoc();
    return $select;
  }

  public function getSecret() {
    if($secret = $this->select(['secret'])) {
      return $secret['secret'];
    }
    return false;
  }

  public function setSecret() {
    $g = new Google2FA();
    $secret = $g->generateSecretKey(64);
    db_insert($this->table)->fields([
      'uid' => $this->uid,
      'secret' => $secret,
    ])->execute();
    return $secret;
  }

  public function enable($enable = 0) {
    return db_update($this->table)
          ->fields(['enabled' => $enable])
          ->condition('uid', $this->uid, '=')
          ->execute();
  }

  public function enabled() {
    $enabled = db_select($this->table, 'a')
          ->fields('a', ['enabled'])
          ->condition('uid', $this->uid, '=')
          ->execute()
          ->fetchAssoc();
    return $enabled['enabled'];
  }
}
